package com.unissoft.basic.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.basic.model.BasicDeviceConfigTemperature;
import com.unissoft.basic.service.BasicDeviceConfigTemperatureService;
import com.unissoft.common.MyConstant;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.UUID;

/**
 * <p>
 * 设备配置—控温 前端控制器
 * </p>
 *
 * @author root
 * @since 2023-02-02
 */
@Api(tags = "设备配置—控温")
@Slf4j
@RestController
@RequestMapping("/basic-device-config-temperature")
public class BasicDeviceConfigTemperatureController {
    private BasicDeviceConfigTemperatureService temperatureService;

    @Autowired
    public void setBasicDeviceConfigTemperatureController(BasicDeviceConfigTemperatureService temperatureService) {
        this.temperatureService = temperatureService;
    }

    @ApiOperation(value = "设备配置—控温", notes = "根据id查询")
    @GetMapping("/authority/getTemperatureById/{id}")
    public ResultView getTemperatureById(@PathVariable String id) {
        BasicDeviceConfigTemperature temperature = temperatureService.getById(id);
        return ResultView.success(temperature);
    }

//    @GetMapping("/authority/getTemperatureList")
//    @ApiOperation(value = "设备配置—控温", notes = "查询list")
//    public ResultView getTemperatureList(@PathParam("name") String name, @PathParam("code") String code) {
//        List<BasicDeviceConfigTemperature> list = temperatureService.getTemperatureList(name, code);
//        return ResultView.success(list);
//    }


    @PostMapping("/getTemperaturePage")
    @ApiOperation(value = "设备配置—控温", notes = "分页列表")
    public ResultView getTemperaturePage(@RequestBody PageParam pageParam) {
        try {
            IPage<BasicDeviceConfigTemperature> page = temperatureService.getTemperaturePage(pageParam);
            return ResultView.success(page);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @PostMapping("/save")
    @ApiOperation(value = "设备配置—控温", notes = "新增保存")
    public ResultView saveTemperature(@RequestBody BasicDeviceConfigTemperature basicDeviceConfigTemperature) {
        basicDeviceConfigTemperature.setId(UUID.randomUUID().toString());
        try {
            temperatureService.saveTwo(basicDeviceConfigTemperature);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
        return ResultView.success();
//        boolean save = temperatureService.save(basicDeviceConfigTemperature);
//        if (save){
//            return ResultView.success();
//        }else{
//            return ResultView.error();
//        }
    }


    @PostMapping("/update")
    @ApiOperation(value = "设备配置—控温", notes = "根据id更新")
    public ResultView updateTemperature(@RequestBody BasicDeviceConfigTemperature BasicDeviceConfigTemperature) {
        boolean b = temperatureService.updateById(BasicDeviceConfigTemperature);
        if (b){
            return ResultView.success();
        }else{
            return ResultView.error();
        }

    }

    @GetMapping("/deleteById/{id}")
    @ApiOperation(value = "设备配置—控温", notes = "根据id删除")
    public ResultView getByIdForTemperatureDelete(@PathVariable String id) {
        if (temperatureService.removeById(id)) {
            return ResultView.success();
        }
        return ResultView.error(MyConstant.ID_NULL);
    }

}
