package com.unissoft.basic.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.basic.model.BasicEnum;
import com.unissoft.basic.service.BasicEnumService;
import com.unissoft.common.DateUtils;
import com.unissoft.common.MyConstant;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.UUID;

/**
 * <p>
 * 字典表 前端控制器
 * </p>
 *
 * @author root
 * @since 2023-01-31
 */
@RestController
@RequestMapping("/basic-enum")
@Api(tags = "字典管理")
public class BasicEnumController {
    @Resource
    private BasicEnumService basicEnumService;

    @PostMapping("/save")
    @ApiOperation(value = "新增/添加子项", notes = "")
    public ResultView save(@RequestBody BasicEnum basicEnum) {
        basicEnum.setId(UUID.randomUUID().toString());
        basicEnum.setCreateTime(DateUtils.getDate());
        boolean save = basicEnumService.save(basicEnum);
        if (save)
            return ResultView.success();
        else
            return ResultView.error();
    }

    @PostMapping("/update")
    @ApiOperation(value = "修改", notes = "根据id修改")
    public ResultView update(@RequestBody BasicEnum basicEnum) {
        basicEnum.setCreateTime(DateUtils.getDate());
        boolean save = basicEnumService.updateById(basicEnum);
        if (save)
            return ResultView.success();
        else
            return ResultView.error();
    }

    @GetMapping("/getById/{id}")
    @ApiOperation(value = "根据id查询单个对象", notes = "")
    public ResultView getByiId(@PathVariable String id) {
        return ResultView.success(basicEnumService.getById(id));
    }

    @GetMapping("/deleteById/{id}")
    @ApiOperation(value = "根据id删除", notes = "")
    public ResultView getByIdForUserDelete(@PathVariable String id) {
        if (basicEnumService.removeById(id)) {
            return ResultView.success();
        }
        return ResultView.error(MyConstant.ID_NULL);
    }

    @PostMapping("/getPageList")
    @ApiOperation(value = "分页列表", notes = "树型列表,顶级参与分页")
    public ResultView getPageList(@RequestBody PageParam pageParam) {
        try {
            IPage<BasicEnum> pageList = basicEnumService.getPageList(pageParam);
            return ResultView.success(pageList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @GetMapping("/getListOrGroupList/{enumCode}")
    @ApiOperation(value = "获取字典数组数据", notes = "传入enumCode获取单组数据,enumCode为空时返回全部")
    public ResultView getListOrGroupList(@PathVariable String enumCode) {
        try {
            return ResultView.success(basicEnumService.getListOrGroupList(enumCode));
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @GetMapping("/getParentsList")
    @ApiOperation(value = "父级列表", notes = "顶级父级列表")
    public ResultView getParentsList() {
        try {
            List<BasicEnum> parentsList = basicEnumService.getParentsList();
            return ResultView.success(parentsList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

}
