package com.unissoft.basic.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.model.BasicGasAlarm;
import com.unissoft.basic.model.BasicTemperatureAlarm;
import com.unissoft.basic.service.BasicGasAlarmService;
import com.unissoft.basic.service.BasicTemperatureAlarmService;
import com.unissoft.common.R;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.UUID;

/**
 * <p>
 * 温度报警 前端控制器
 * </p>
 *
 * @author root
 * @since 2023-02-09
 */
@RestController
@Api(tags = "温度报警")
@RequestMapping("/basic-temperature-alarm")
public class BasicTemperatureAlarmController {

    @Autowired
    private BasicTemperatureAlarmService basicTemperatureAlarmService;

    @ApiOperation(value = "温度报警查询")
    @GetMapping("/getAll")
    @ApiImplicitParams({
            @ApiImplicitParam(name="currentPage",value="当前页",paramType = "query",required=false),
            @ApiImplicitParam(name="pageSize",value="当前页记录数",paramType = "query",required=false),
            @ApiImplicitParam(name="alarmType",value="分类名称或编号",paramType = "query",required=false),
    })
    public R<Page<BasicTemperatureAlarm>> getAll(@RequestParam(name ="currentPage",required=false) Integer currentPage,
                                                 @RequestParam(name ="pageSize",required=false) Integer pageSize,
                                                 @RequestParam(name ="alarmType",required=false) String alarmType) {

        currentPage = currentPage==null ? 1: currentPage;
        pageSize = pageSize==null ? 10: pageSize;
        Page<BasicTemperatureAlarm> page = new Page<>(currentPage,pageSize);
        Page<BasicTemperatureAlarm> BasicGasAlarm = basicTemperatureAlarmService.selectBasicTemperatureAlarm(alarmType, page);
        return R.SUCCESS(BasicGasAlarm);
    }

    @RequestMapping(value = "/insertBasicTemperatureAlarm",method = RequestMethod.POST)
    @ApiOperation("新增温度报警")
    public R< BasicTemperatureAlarm> insertBasicTemperatureAlarm(@RequestBody@ApiParam(name = "BasicTemperatureAlarm对象",value ="",required = true ) BasicTemperatureAlarm basicTemperatureAlarm){
        try {
            basicTemperatureAlarm.setId(UUID.randomUUID().toString());
            basicTemperatureAlarmService.save(basicTemperatureAlarm);
            return R.SUCCESS(basicTemperatureAlarm);
        }catch (Exception e) {
            return R.ERROR(e.getMessage());
        }
    }

    @RequestMapping(value = "/updateBasicTemperatureAlarm",method = RequestMethod.PUT)
    @ApiOperation("修改温度报警")
    public R< BasicTemperatureAlarm> updateBasicTemperatureAlarm(@RequestBody  BasicTemperatureAlarm basicTemperatureAlarm){
        try {
            basicTemperatureAlarmService.updateById(basicTemperatureAlarm);
            return R.SUCCESS(basicTemperatureAlarm);
        }catch (Exception e) {
            return R.ERROR(e.getMessage());
        }
    }
    @RequestMapping(value = "/deleteBasicTemperatureAlarm",method = RequestMethod.PUT)
    @ApiOperation("删除温度报警")
    public R< BasicTemperatureAlarm> deleteBasicTemperatureAlarm(@RequestBody  BasicTemperatureAlarm basicTemperatureAlarm){
        try {
            basicTemperatureAlarmService.removeById(basicTemperatureAlarm);
            return R.SUCCESS(basicTemperatureAlarm);
        }catch (Exception e) {
            return R.ERROR(e.getMessage());
        }
    }


}
