package com.unissoft.basic.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.basic.model.BasicTimingTask;
import com.unissoft.basic.service.BasicTimingTaskService;
import com.unissoft.common.MyConstant;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 定时任务设置表 前端控制器
 * </p>
 *
 * @author root
 * @since 2023-02-06
 */
@Api(tags = "定时任务配置")
@RestController
@RequestMapping("/basic-timing-task")
public class BasicTimingTaskController {
    @Resource
    private BasicTimingTaskService timingTaskService;

    @PostMapping("/save")
    @ApiOperation(value = "新增", notes = "")
    public ResultView saveList(@RequestBody BasicTimingTask timingTask) {
        try {
            timingTaskService.saveList(timingTask);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
        return ResultView.success();
    }

    @PostMapping("/update")
    @ApiOperation(value = "定时任务设置", notes = "修改")
    public ResultView update(@RequestBody BasicTimingTask timingTask) {
        try {
            timingTaskService.updateList(timingTask);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
        return ResultView.success();
    }

    @ApiOperation(value = "根据id查询", notes = "详情")
    @GetMapping("/getById/{id}")
    public ResultView getById(@PathVariable String id) {
        BasicTimingTask timingTask = timingTaskService.getById(id);
        return ResultView.success(timingTask);
    }

    @PostMapping("/deleteById")
    @ApiOperation(value = "根据id删除", notes = "需要删除定时任务id,beanName,methodName,methodParams必传")
    public ResultView deleteById(@RequestBody BasicTimingTask timingTask) {
        if (timingTaskService.deleteById(timingTask)) {
            return ResultView.success();
        }
        return ResultView.error(MyConstant.ID_NULL);
    }

    @PostMapping("/getPageList")
    @ApiOperation(value = "分页列表", notes = "")
    public ResultView getPageList(@RequestBody PageParam pageParam) {
        try {
            IPage<BasicTimingTask> pageList = timingTaskService.getPageList(pageParam);
            return ResultView.success(pageList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    // 关联设备 TODO
    @ApiOperation(value = "关联设备名称查询", notes = "设备分类名称")
    @GetMapping("/getByDeviceName/{classifyName}")
    public ResultView getByDeviceName(@PathVariable String classifyName) {
        List<Map<String, Object>> device = timingTaskService.getByDeviceName(classifyName);
        return ResultView.success(device);
    }

}
