package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.model.BasicDeviceClassify;
import com.unissoft.basic.mapper.BasicDeviceClassifyMapper;
import com.unissoft.basic.model.BasicEnum;
import com.unissoft.basic.service.BasicDeviceClassifyService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.PageParam;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 设备配置-设备分类 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-03-02
 */
@Service
public class BasicDeviceClassifyServiceImpl extends ServiceImpl<BasicDeviceClassifyMapper, BasicDeviceClassify> implements BasicDeviceClassifyService {
    @Resource
    private BasicDeviceClassifyMapper basicDeviceClassifyMapper;

    /**
     * 分页查询列表数据
     * 1.使用递归查询数据库,影响数据库性能(未采用)
     * 2.使用java获取所有数据在递归处理数据,在数据量不大的情况下性能较高采用
     *
     * @param pageParam 分页条件
     * @return page
     */
    @Override
    public IPage<BasicDeviceClassify> getPageList(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicDeviceClassify> ew = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicDeviceClassify basicDeviceClassify = JSON.parseObject(condition, BasicDeviceClassify.class);
            // 获取查询条件
            String classifyName = basicDeviceClassify.getClassifyName();
            String classifyIdentifying = basicDeviceClassify.getClassifyIdentifying();
            if (!StringUtils.isEmpty(classifyName))
                ew.like("enum_name", classifyName);
            if (!StringUtils.isEmpty(classifyIdentifying))
                ew.like("classify_identifying", classifyIdentifying);
        }
        // 只获取顶级父类作为分页数据
        ew.eq("parent_id", "0");
        ew.orderByDesc("create_time");
        IPage<BasicDeviceClassify> page = new Page<>(pageIndex, pageSize);
        IPage<BasicDeviceClassify> enumPage = basicDeviceClassifyMapper.getEnumPage(page, ew);
        // 调用子集
        if (enumPage.getSize() > 0) {
            List<BasicDeviceClassify> basicEnums = this.queryList();
            // 已经查询定义好的分页数据比对添加子集的数据(已排序,可以减少循环次数)
            enumPage.getRecords().forEach(e ->
                    basicEnums.forEach(l -> {
                        if (e.getId().equals(l.getId())) {
                            e.setChildren(l.getChildren());
                        }
                    })
            );
        }
        return enumPage;
    }

    @Override
    public List<BasicDeviceClassify> getParentList(String classifyName) {
        QueryWrapper<BasicDeviceClassify> ew = new QueryWrapper<>();
        ew.orderByDesc("create_time");
        ew.eq("parent_id", "0");
        if (!StringUtils.isEmpty(classifyName))
            ew.like("classify_name", classifyName);
        return basicDeviceClassifyMapper.selectList(ew);
    }

    /**
     * 查询所有设备分类数据
     *
     * @return page
     */
    private List<BasicDeviceClassify> queryList() {
        // 查询对象
        QueryWrapper<BasicDeviceClassify> ew = new QueryWrapper<>();
        ew.orderByDesc("create_time");
        List<BasicDeviceClassify> allList = basicDeviceClassifyMapper.selectList(ew);
        List<BasicDeviceClassify> childList = this.getChildren(allList, "0");
        this.fillTree(allList, childList);
        return childList;
    }

    /**
     * 所有数据集分级
     *
     * @param allList  所有数据集
     * @param parentId 定义顶级父级parentId("0")
     * @return list
     */
    private List<BasicDeviceClassify> getChildren(List<BasicDeviceClassify> allList, String parentId) {
        List<BasicDeviceClassify> children = new ArrayList<>();
        for (BasicDeviceClassify be : allList) {
            // 遍历出父id等于参数的id,add进子节点集合
            if (be.getParentId().equals(parentId)) {
                children.add(be);
            }
        }
        return children;
    }

    /**
     * 递归拼装树型菜单
     *
     * @param allList   所有数据集
     * @param childList 递归方法
     */
    private void fillTree(List<BasicDeviceClassify> allList, List<BasicDeviceClassify> childList) {
        if (childList.size() > 0) {
            for (BasicDeviceClassify be : childList) {
                List<BasicDeviceClassify> childList1 = this.getChildren(allList, be.getId());
                fillTree(allList, childList1);
                be.setChildren(childList1);
            }
        }
    }

}
