package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.mapper.BasicDeviceConfigEnergyMapper;
import com.unissoft.basic.mapper.BasicWarrantyPreserveMapper;
import com.unissoft.basic.model.BasicDeviceConfigEnergy;
import com.unissoft.basic.model.BasicWarrantyPreserve;
import com.unissoft.basic.service.BasicDeviceConfigEnergyService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.PageParam;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * <p>
 * 设备配置—能耗 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-02
 */
@Service
public class BasicDeviceConfigEnergyServiceImpl extends ServiceImpl<BasicDeviceConfigEnergyMapper, BasicDeviceConfigEnergy> implements BasicDeviceConfigEnergyService {
    @Resource
    private BasicDeviceConfigEnergyMapper energyMapper;
    @Resource
    private BasicWarrantyPreserveMapper warrantyPreserveMapper;
    @Override
    public IPage<BasicDeviceConfigEnergy> getEnergyPage(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicDeviceConfigEnergy> energyQW = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicDeviceConfigEnergy energy = JSON.parseObject(condition, BasicDeviceConfigEnergy.class);
            // 获取查询条件
            String deviceNumber = energy.getDeviceNumber();
            String deviceName = energy.getDeviceName();
            //Integer qos = energy.getProtocolQos();
            if (!StringUtils.isEmpty(deviceNumber)){
                energyQW.like("device_number", deviceNumber);
            }
            if (!StringUtils.isEmpty(deviceName)){
                energyQW.like("device_name", deviceName);
                //ew.eq("protocol_qos", qos);
            }

        }
        energyQW.orderByDesc("create_time");
        IPage<BasicDeviceConfigEnergy> page = new Page<>(pageIndex, pageSize);
        return energyMapper.selectPage(page, energyQW);

    }

    @Override
    public void saveTwo(BasicDeviceConfigEnergy energy) {
        energyMapper.insert(energy);
        BasicWarrantyPreserve warrantyPreserve = new BasicWarrantyPreserve();
        warrantyPreserve.setId(UUID.randomUUID().toString());
        warrantyPreserve.setAssetName(energy.getDeviceName());//资产名称
        warrantyPreserve.setAssetNo(energy.getDeviceNumber());//资产编号
        warrantyPreserve.setHouseCode(energy.getHouseCode());
        warrantyPreserve.setOrgCode(energy.getOrgCode());
        warrantyPreserve.setDeviceId(energy.getId());
        warrantyPreserve.setWarrantyTime(energy.getWarrantyTime());
        warrantyPreserve.setIsPreserve("0");
        warrantyPreserve.setPreserveTime(energy.getLastSeenTime());
        warrantyPreserve.setSurplusTime("30");//剩余时间
        warrantyPreserveMapper.insert(warrantyPreserve);
    }
}
