package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.mapper.BasicDeviceConfigLightingMapper;
import com.unissoft.basic.mapper.BasicWarrantyPreserveMapper;
import com.unissoft.basic.model.BasicDeviceConfigLighting;
import com.unissoft.basic.model.BasicWarrantyPreserve;
import com.unissoft.basic.service.BasicDeviceConfigLightingService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.PageParam;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * <p>
 * 设备配置—照明 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-02
 */
@Service
public class BasicDeviceConfigLightingServiceImpl extends ServiceImpl<BasicDeviceConfigLightingMapper, BasicDeviceConfigLighting> implements BasicDeviceConfigLightingService {
    @Resource
    private BasicDeviceConfigLightingMapper lightingMapper;
    @Resource
    private BasicWarrantyPreserveMapper warrantyPreserveMapper;
    @Override
    public IPage<BasicDeviceConfigLighting> getLightingPage(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicDeviceConfigLighting> lightingQW = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicDeviceConfigLighting lighting = JSON.parseObject(condition, BasicDeviceConfigLighting.class);
            // 获取查询条件
            String deviceNumber = lighting.getDeviceNumber();
            String deviceName = lighting.getDeviceName();
            //Integer qos = lighting.getProtocolQos();
            if (!StringUtils.isEmpty(deviceNumber)){
                lightingQW.like("device_number", deviceNumber);
            }
            if (!StringUtils.isEmpty(deviceName)){
                lightingQW.like("device_name", deviceName);
                //ew.eq("protocol_qos", qos);
            }

        }
        lightingQW.orderByDesc("create_time");
        IPage<BasicDeviceConfigLighting> page = new Page<>(pageIndex, pageSize);
        return lightingMapper.selectPage(page, lightingQW);

    }

    @Override
    public void saveTwo(BasicDeviceConfigLighting lighting) {
        lightingMapper.insert(lighting);
        BasicWarrantyPreserve warrantyPreserve = new BasicWarrantyPreserve();
        warrantyPreserve.setId(UUID.randomUUID().toString());
        warrantyPreserve.setAssetName(lighting.getDeviceName());//资产名称
        warrantyPreserve.setAssetNo(lighting.getDeviceNumber());//资产编号
        warrantyPreserve.setHouseCode(lighting.getHouseCode());
        warrantyPreserve.setOrgCode(lighting.getOrgCode());
        warrantyPreserve.setDeviceId(lighting.getId());
        warrantyPreserve.setWarrantyTime(lighting.getWarrantyTime());
        warrantyPreserve.setIsPreserve("0");
        warrantyPreserve.setPreserveTime(lighting.getLastSeenTime());
        warrantyPreserve.setSurplusTime("30");//剩余时间
        warrantyPreserveMapper.insert(warrantyPreserve);
    }
}
