package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.mapper.BasicDeviceConfigTemperatureMapper;
import com.unissoft.basic.mapper.BasicWarrantyPreserveMapper;
import com.unissoft.basic.model.BasicDeviceConfigAtmosphere;
import com.unissoft.basic.model.BasicDeviceConfigTemperature;
import com.unissoft.basic.model.BasicDeviceConfigTemperature;
import com.unissoft.basic.mapper.BasicDeviceConfigTemperatureMapper;
import com.unissoft.basic.model.BasicWarrantyPreserve;
import com.unissoft.basic.service.BasicDeviceConfigTemperatureService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.PageParam;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * <p>
 * 设备配置—控温 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-02
 */
@Service
public class BasicDeviceConfigTemperatureServiceImpl extends ServiceImpl<BasicDeviceConfigTemperatureMapper, BasicDeviceConfigTemperature> implements BasicDeviceConfigTemperatureService {
    @Resource
    private BasicDeviceConfigTemperatureMapper temperatureMapper;
    @Resource
    private BasicWarrantyPreserveMapper warrantyPreserveMapper;
    @Override
    public IPage<BasicDeviceConfigTemperature> getTemperaturePage(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicDeviceConfigTemperature> temperatureQW = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicDeviceConfigTemperature temperature = JSON.parseObject(condition, BasicDeviceConfigTemperature.class);
            // 获取查询条件
            String deviceNumber = temperature.getDeviceNumber();
            String deviceName = temperature.getDeviceName();
            //Integer qos = temperature.getProtocolQos();
            if (!StringUtils.isEmpty(deviceNumber)){
                temperatureQW.like("device_number", deviceNumber);
            }
            if (!StringUtils.isEmpty(deviceName)){
                temperatureQW.like("device_name", deviceName);
                //ew.eq("protocol_qos", qos);
            }

        }
        temperatureQW.orderByDesc("create_time");
        IPage<BasicDeviceConfigTemperature> page = new Page<>(pageIndex, pageSize);
        return temperatureMapper.selectPage(page, temperatureQW);

    }

    @Override
    public void saveTwo(BasicDeviceConfigTemperature temperature) {
        temperatureMapper.insert(temperature);
        BasicWarrantyPreserve warrantyPreserve = new BasicWarrantyPreserve();
        warrantyPreserve.setId(UUID.randomUUID().toString());
        warrantyPreserve.setAssetName(temperature.getDeviceName());//资产名称
        warrantyPreserve.setAssetNo(temperature.getDeviceNumber());//资产编号
        warrantyPreserve.setHouseCode(temperature.getHouseCode());
        warrantyPreserve.setOrgCode(temperature.getOrgCode());
        warrantyPreserve.setDeviceId(temperature.getId());
        warrantyPreserve.setWarrantyTime(temperature.getWarrantyTime());
        warrantyPreserve.setIsPreserve("0");
        warrantyPreserve.setPreserveTime(temperature.getLastSeenTime());
        warrantyPreserve.setSurplusTime("30");//剩余时间
        warrantyPreserveMapper.insert(warrantyPreserve);
    }
}
