package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.mapper.BasicDeviceConfigWindMapper;
import com.unissoft.basic.mapper.BasicWarrantyPreserveMapper;
import com.unissoft.basic.model.BasicDeviceConfigWind;
import com.unissoft.basic.model.BasicWarrantyPreserve;
import com.unissoft.basic.service.BasicDeviceConfigWindService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.PageParam;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * <p>
 * 设备配置—通风 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-02
 */
@Service
public class BasicDeviceConfigWindServiceImpl extends ServiceImpl<BasicDeviceConfigWindMapper, BasicDeviceConfigWind> implements BasicDeviceConfigWindService {
    @Resource
    private BasicDeviceConfigWindMapper windMapper;
    @Resource
    private BasicWarrantyPreserveMapper warrantyPreserveMapper;

    @Override
    public IPage<BasicDeviceConfigWind> getWindPage(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicDeviceConfigWind> windQW = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicDeviceConfigWind wind = JSON.parseObject(condition, BasicDeviceConfigWind.class);
            // 获取查询条件
            String deviceNumber = wind.getDeviceNumber();
            String deviceName = wind.getDeviceName();
            //Integer qos = wind.getProtocolQos();
            if (!StringUtils.isEmpty(deviceNumber)){
                windQW.like("device_number", deviceNumber);
            }
            if (!StringUtils.isEmpty(deviceName)){
                windQW.like("device_name", deviceName);
                //ew.eq("protocol_qos", qos);
            }

        }
        windQW.orderByDesc("create_time");
        IPage<BasicDeviceConfigWind> page = new Page<>(pageIndex, pageSize);
        return windMapper.selectPage(page, windQW);

    }

    @Override
    public void saveTwo(BasicDeviceConfigWind wind) {
        windMapper.insert(wind);
        BasicWarrantyPreserve warrantyPreserve = new BasicWarrantyPreserve();
        warrantyPreserve.setId(UUID.randomUUID().toString());
        warrantyPreserve.setAssetName(wind.getDeviceName());//资产名称
        warrantyPreserve.setAssetNo(wind.getDeviceNumber());//资产编号
        warrantyPreserve.setHouseCode(wind.getHouseCode());
        warrantyPreserve.setOrgCode(wind.getOrgCode());
        warrantyPreserve.setDeviceId(wind.getId());
        warrantyPreserve.setWarrantyTime(wind.getWarrantyTime());
        warrantyPreserve.setIsPreserve("0");
        warrantyPreserve.setPreserveTime(wind.getLastSeenTime());
        warrantyPreserve.setSurplusTime("30");//剩余时间
        warrantyPreserveMapper.insert(warrantyPreserve);
    }
}
