package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.basic.mapper.BasicEnumMapper;
import com.unissoft.basic.model.BasicEnum;
import com.unissoft.basic.service.BasicEnumService;
import com.unissoft.common.PageParam;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 字典表 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-01-31
 */
@Service
public class BasicEnumServiceImpl extends ServiceImpl<BasicEnumMapper, BasicEnum> implements BasicEnumService {
    @Resource
    private BasicEnumMapper basicEnumMapper;

    /**
     * 分页查询列表数据
     * 1.使用递归查询数据库,影响数据库性能(未采用)
     * 2.使用java获取所有数据在递归处理数据,在数据量不大的情况下性能较高采用
     *
     * @param pageParam 分页条件
     * @return page
     */
    @Override
    public IPage<BasicEnum> getPageList(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicEnum> ew = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicEnum basicEnum = JSON.parseObject(condition, BasicEnum.class);
            // 获取查询条件
            String enumName = basicEnum.getEnumName();
            String enumCode = basicEnum.getEnumCode();
            if (!StringUtils.isEmpty(enumName))
                ew.like("enum_name", enumName);
            if (!StringUtils.isEmpty(enumCode))
                ew.eq("enum_code", enumCode);
        }
        // 只获取顶级父类作为分页数据
        ew.eq("parent_id", "0");
        ew.orderByDesc("create_time");
        IPage<BasicEnum> page = new Page<>(pageIndex, pageSize);
        IPage<BasicEnum> enumPage = basicEnumMapper.getEnumPage(page, ew);
        // 调用子集
        if (enumPage.getSize() > 0) {
            List<BasicEnum> basicEnums = this.queryList();
            // 已经查询定义好的分页数据比对添加子集的数据(已排序,可以减少循环次数)
            enumPage.getRecords().forEach(e ->
                    basicEnums.forEach(l -> {
                        if (e.getId().equals(l.getId())) {
                            e.setChildren(l.getChildren());
                        }
                    })
            );
        }
        return enumPage;
    }

    @Override
    public Object getListOrGroupList(String enumCode) {
        // enumCode 为空返回所有数据(tree)
        if (enumCode.equals("\"\"") || enumCode.equals("null") || enumCode.equals("''")) {
            return this.queryList();
        } else { // enumCode 非空返回父级下一级的数据
            return basicEnumMapper.getListOrGroupList(enumCode);
        }
    }

    @Override
    public List<BasicEnum> getParentsList() {
        return basicEnumMapper.getParentsList();
    }

    /**
     * 查询所有字典数据
     *
     * @return page
     */
    private List<BasicEnum> queryList() {
        // 查询对象
        QueryWrapper<BasicEnum> ew = new QueryWrapper<>();
        ew.orderByDesc("create_time");
        List<BasicEnum> allList = basicEnumMapper.selectList(ew);
        List<BasicEnum> childList = this.getChildren(allList, "0");
        this.fillTree(allList, childList);
        return childList;
    }

    /**
     * 所有数据集分级
     *
     * @param allList  所有数据集
     * @param parentId 定义顶级父级parentId("0")
     * @return list
     */
    private List<BasicEnum> getChildren(List<BasicEnum> allList, String parentId) {
        List<BasicEnum> children = new ArrayList<>();
        for (BasicEnum be : allList) {
            // 遍历出父id等于参数的id,add进子节点集合
            if (be.getParentId().equals(parentId)) {
                children.add(be);
            }
        }
        return children;
    }

    /**
     * 递归拼装树型菜单
     *
     * @param allList   所有数据集
     * @param childList 递归方法
     */
    private void fillTree(List<BasicEnum> allList, List<BasicEnum> childList) {
        if (childList.size() > 0) {
            for (BasicEnum be : childList) {
                List<BasicEnum> childList1 = this.getChildren(allList, be.getId());
                fillTree(allList, childList1);
                be.setChildren(childList1);
            }
        }
    }

}
