package com.unissoft.basic.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.model.BasicRemoteProtocol;
import com.unissoft.basic.mapper.BasicRemoteProtocolMapper;
import com.unissoft.basic.service.BasicRemoteProtocolService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.PageParam;
import com.unissoft.utils.MapConvertUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 通讯协议表 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-06
 */
@Service
public class BasicRemoteProtocolServiceImpl extends ServiceImpl<BasicRemoteProtocolMapper, BasicRemoteProtocol> implements BasicRemoteProtocolService {
    @Resource
    private BasicRemoteProtocolMapper remoteProtocolMapper;
    @Resource
    private MapConvertUtils convertUtils;

    @Override
    public IPage<BasicRemoteProtocol> getPageList(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<BasicRemoteProtocol> ew = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            BasicRemoteProtocol remoteProtocol = JSON.parseObject(condition, BasicRemoteProtocol.class);
            // 获取查询条件
            String protocolType = remoteProtocol.getProtocolType();
            Integer qos = remoteProtocol.getProtocolQos();
            if (!StringUtils.isEmpty(protocolType))
                ew.like("protocol_type", protocolType);
            if (!StringUtils.isEmpty(qos))
                ew.eq("protocol_qos", qos);
        }
        // 只获取顶级父类作为分页数据
        ew.orderByDesc("build_time");
        IPage<BasicRemoteProtocol> page = new Page<>(pageIndex, pageSize);
        return remoteProtocolMapper.selectPage(page, ew);
    }

    @Override
    public String getByTopics() {
        return convertUtils.joiningList(remoteProtocolMapper.getByTopics());
    }
}
