package com.unissoft.basic.service.impl;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.unissoft.basic.mapper.BasicTimingTaskMapper;
import com.unissoft.basic.model.BasicTimingTask;
import com.unissoft.common.CronTaskRegistrar;
import com.unissoft.common.SchedulingRunnable;
import com.unissoft.enums.SysJobStatus;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author qingsong.han
 * @description: 实现了CommandLineRunner接口的SysJobRunner类, 当spring boot项目启动完成后,加载数据库里状态为正常的定时任务
 * @create 2022-06-27 16:12
 */
@Slf4j
@Service
public class SysJobRunner implements CommandLineRunner {

    @Resource
    private BasicTimingTaskMapper timingTaskMapper;
    @Resource
    private CronTaskRegistrar cronTaskRegistrar;

    @Override
    public void run(String... args) {
        // 初始加载数据库里状态为正常的定时任务
        List<BasicTimingTask> jobList = timingTaskMapper.findByJobStatus(SysJobStatus.NORMAL.ordinal());
        if (CollectionUtils.isNotEmpty(jobList)) {
            for (BasicTimingTask job : jobList) {
                SchedulingRunnable task = new SchedulingRunnable(job.getBeanName(), job.getMethodName(), job.getMethodParams());
                cronTaskRegistrar.addCronTask(task, job.getDetectionCron());
            }
            log.info("定时任务已加载完毕...");
        } else {
            log.info("没有可执行的定时任务列表...");
        }
    }

}
