package com.unissoft.data.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.data.mapper.DataAirtightnessMapper;
import com.unissoft.data.model.DataAirtightness;
import com.unissoft.data.service.DataAirtightnessService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.Objects;

/**
 * <p>
 * 气密性数据 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-28
 */
@Service
public class DataAirtightnessServiceImpl extends ServiceImpl<DataAirtightnessMapper, DataAirtightness> implements DataAirtightnessService {
    @Resource
    private DataAirtightnessMapper airtightnessMapper;

    @Override
    public IPage<DataAirtightness> getPageList(PageParam pageParam) {
        // 创建分页条件对象
        IPage<DataAirtightness> page = new Page<>(pageParam.getPageIndex(), pageParam.getPageSize());
        // 查询对象
        QueryWrapper<DataAirtightness> qw = new QueryWrapper<>();
        // 解析查询条件
        String condition = pageParam.getCondition();
        if (!StringUtils.isEmpty(condition)) {
            DataAirtightness airTightness = JSON.parseObject(condition, DataAirtightness.class);
            // 查询条件
            String orgCode = airTightness.getOrgCode();
            String houseCode = airTightness.getHouseCode();
            Date timingTime = airTightness.getTimingTime();
            if (!StringUtils.isEmpty(orgCode))
                qw.eq("org_code", orgCode);
            if (!StringUtils.isEmpty(houseCode))
                qw.eq("house_code", houseCode);
            if (Objects.nonNull(timingTime))
                qw.between("timing_time", DateUtils.betweenOneDay(timingTime)[0], DateUtils.betweenOneDay(timingTime)[1]);
        }
        qw.orderByDesc("timing_time");
        return airtightnessMapper.selectPage(page, qw);
    }
}
