package com.unissoft.data.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.data.mapper.DataAlarmInfoMapper;
import com.unissoft.data.model.DataAlarmInfo;
import com.unissoft.data.service.DataAlarmInfoService;
import lombok.extern.slf4j.Slf4j;
import net.bytebuddy.implementation.bytecode.Throw;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-03-06
 */
@Slf4j
@Service
public class DataAlarmInfoServiceImpl extends ServiceImpl<DataAlarmInfoMapper, DataAlarmInfo> implements DataAlarmInfoService {
    @Resource
    private DataAlarmInfoMapper alarmInfoMapper;

    @Override
    public List<DataAlarmInfo> getAlarmInfoList(String orgCode) {
        QueryWrapper<DataAlarmInfo> qw = new QueryWrapper<>();
        if (!StringUtils.isEmpty(orgCode))
            qw.eq("org_code", orgCode);
        // 查询当天日志数据
        Date date = new Date();
        qw.between("alarm_time", DateUtils.betweenOneDay(date)[0], DateUtils.betweenOneDay(date)[1]);
        // 降序
        qw.orderByDesc("alarm_time");
        List<DataAlarmInfo> alarmInfo = alarmInfoMapper.selectList(qw);
        // 当天数据为空,获取最新10条
        if (alarmInfo.size() <= 0) {
            alarmInfo = alarmInfoMapper.selectPage(new Page<>(0, 10), qw).getRecords();
        }
        return alarmInfo;
    }

    // TODO
    @Override
    public boolean saveAlarmInfo(Object data, String alarmType) {
        switch (alarmType) {
            case "001":
                this.tempType(data);
                break;
            case "002":
                this.ventilateType(data);
                break;
            case "003":
                this.lightType(data);
                break;
            default:
                return false;
        }
        return true;
    }

    private void tempType(Object data) {
        log.info("temperature alarm data: {}", data);
    }

    private void ventilateType(Object data) {
        log.info("ventilate alarm data: {}", data);
    }

    private void lightType(Object data) {
        log.info("light alarm data: {}", data);
    }

}
