package com.unissoft.data.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.data.mapper.DataGasMapper;
import com.unissoft.data.model.DataGas;
import com.unissoft.data.service.DataGasService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.Objects;

/**
 * <p>
 * 气体检测数据 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-28
 */
@Service
public class DataGasServiceImpl extends ServiceImpl<DataGasMapper, DataGas> implements DataGasService {
    @Resource
    private DataGasMapper gasMapper;

    @Override
    public IPage<DataGas> getPageList(PageParam pageParam) {
        // 创建分页条件对象
        IPage<DataGas> page = new Page<>(pageParam.getPageIndex(), pageParam.getPageSize());
        // 查询对象
        QueryWrapper<DataGas> qw = new QueryWrapper<>();
        // 解析查询条件
        String condition = pageParam.getCondition();
        if (!StringUtils.isEmpty(condition)) {
            DataGas gas = JSON.parseObject(condition, DataGas.class);
            // 查询条件
            String orgCode = gas.getOrgCode();
            String houseCode = gas.getHouseCode();
            Date collectorTime = gas.getCollectorTime();
            if (!StringUtils.isEmpty(orgCode))
                qw.eq("org_code", orgCode);
            if (!StringUtils.isEmpty(houseCode))
                qw.eq("house_code", houseCode);
            if (Objects.nonNull(collectorTime))
                qw.between("collector_time", DateUtils.betweenOneDay(collectorTime)[0], DateUtils.betweenOneDay(collectorTime)[1]);
        }
        qw.orderByDesc("collector_time");
        return gasMapper.selectPage(page, qw);
    }
}
