package com.unissoft.data.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.data.mapper.DataGrainTempMapper;
import com.unissoft.data.model.DataGrainTemp;
import com.unissoft.data.service.DataGrainTempService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 粮温检测数据表 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-28
 */
@Service
public class DataGrainTempServiceImpl extends ServiceImpl<DataGrainTempMapper, DataGrainTemp> implements DataGrainTempService {
    @Resource
    private DataGrainTempMapper grainTempMapper;

    @Override
    public IPage<DataGrainTemp> getPageList(PageParam pageParam) {
        // 创建分页条件对象
        IPage<DataGrainTemp> page = new Page<>(pageParam.getPageIndex(), pageParam.getPageSize());
        // 查询对象
        QueryWrapper<DataGrainTemp> qw = new QueryWrapper<>();
        // 解析查询条件
        String condition = pageParam.getCondition();
        if (!StringUtils.isEmpty(condition)) {
            DataGrainTemp grainTemp = JSON.parseObject(condition, DataGrainTemp.class);
            // 查询条件
            String orgCode = grainTemp.getOrgCode();
            String houseCode = grainTemp.getHouseCode();
            Date checkTime = grainTemp.getCheckTime();
            if (!StringUtils.isEmpty(orgCode)){
                qw.eq("org_code", orgCode);
            }
            if (!StringUtils.isEmpty(houseCode)){
                qw.eq("house_code", houseCode);
            }

            if (Objects.nonNull(checkTime)){
                qw.between("check_time", DateUtils.betweenOneDay(checkTime)[0], DateUtils.betweenOneDay(checkTime)[1]);
            }

        }
        qw.orderByDesc("check_time");
        return grainTempMapper.selectPage(page, qw);
    }

    @Override
    public List<DataGrainTemp> getGainList(String orgCode) {
        QueryWrapper<DataGrainTemp> qw = new QueryWrapper<>();
        if (!StringUtils.isEmpty(orgCode)){
            qw.eq("org_code", orgCode);
        }
        // 查询当天日志数据
        Date date = new Date();
        qw.between("check_time", DateUtils.betweenOneDay(date)[0], DateUtils.betweenOneDay(date)[1]);
        // 降序
        qw.orderByDesc("check_time");
        List<DataGrainTemp> grainList = grainTempMapper.selectList(qw);
        // 当天数据为空,获取最新10条
        if (grainList.size() <= 0) {
            grainList = grainTempMapper.selectPage(new Page<>(0, 10), qw).getRecords();
        }
        return grainList;
    }
}
