package com.unissoft.data.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.data.mapper.DataInsectMapper;
import com.unissoft.data.model.DataInsect;
import com.unissoft.data.service.DataInsectService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.Objects;

/**
 * <p>
 * 虫情检测数据 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-28
 */
@Service
public class DataInsectServiceImpl extends ServiceImpl<DataInsectMapper, DataInsect> implements DataInsectService {
    @Resource
    private DataInsectMapper insectMapper;

    @Override
    public IPage<DataInsect> getPageList(PageParam pageParam) {
        // 创建分页条件对象
        IPage<DataInsect> page = new Page<>(pageParam.getPageIndex(), pageParam.getPageSize());
        // 查询对象
        QueryWrapper<DataInsect> qw = new QueryWrapper<>();
        // 解析查询条件
        String condition = pageParam.getCondition();
        if (!StringUtils.isEmpty(condition)) {
            DataInsect insect = JSON.parseObject(condition, DataInsect.class);
            // 查询条件
            String orgCode = insect.getOrgCode();
            String houseCode = insect.getHouseCode();
            Date collectorTime = insect.getCollectorTime();
            if (!StringUtils.isEmpty(orgCode))
                qw.eq("org_code", orgCode);
            if (!StringUtils.isEmpty(houseCode))
                qw.eq("house_code", houseCode);
            if (Objects.nonNull(collectorTime))
                qw.between("collector_time", DateUtils.betweenOneDay(collectorTime)[0], DateUtils.betweenOneDay(collectorTime)[1]);
        }
        qw.orderByDesc("collector_time");
        return insectMapper.selectPage(page, qw);
    }
}
