package com.unissoft.data.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.data.mapper.DataMeteorologicalMapper;
import com.unissoft.data.model.DataMeteorological;
import com.unissoft.data.service.DataMeteorologicalService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.Objects;

/**
 * <p>
 * 气象站数据 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-02-28
 */
@Service
public class DataMeteorologicalServiceImpl extends ServiceImpl<DataMeteorologicalMapper, DataMeteorological> implements DataMeteorologicalService {
    @Resource
    private DataMeteorologicalMapper meteorologicalMapper;

    @Override
    public IPage<DataMeteorological> getPageList(PageParam pageParam) {
        // 创建分页条件对象
        IPage<DataMeteorological> page = new Page<>(pageParam.getPageIndex(), pageParam.getPageSize());
        // 查询对象
        QueryWrapper<DataMeteorological> qw = new QueryWrapper<>();
        // 解析查询条件
        String condition = pageParam.getCondition();
        if (!StringUtils.isEmpty(condition)) {
            DataMeteorological meteorological = JSON.parseObject(condition, DataMeteorological.class);
            // 查询条件
            String orgCode = meteorological.getOrgCode();
            String deviceCode = meteorological.getDeviceCode();
            Date collectorTime = meteorological.getCollectorTime();
            if (!StringUtils.isEmpty(orgCode))
                qw.eq("org_code", orgCode);
            if (!StringUtils.isEmpty(deviceCode))
                qw.eq("device_code", deviceCode);
            if (Objects.nonNull(collectorTime))
                qw.between("collector_time", DateUtils.betweenOneDay(collectorTime)[0], DateUtils.betweenOneDay(collectorTime)[1]);
        }
        qw.orderByDesc("collector_time");
        return meteorologicalMapper.selectPage(page, qw);
    }
}
