package com.unissoft.house.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.common.*;
import com.unissoft.house.model.HouseInfo;
import com.unissoft.house.service.HouseInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import javax.websocket.server.PathParam;
import java.util.List;
import java.util.UUID;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author root
 * @since 2023-01-17
 */
@Api(tags = "仓房管理")
@Slf4j
@RestController
@RequestMapping("/house-info")
public class HouseInfoController {

    private HouseInfoService houseInfoService;

    @Autowired
    public void setHouseInfoController(HouseInfoService houseInfoService) {
        this.houseInfoService = houseInfoService;
    }

    @ApiOperation(value = "仓房管理", notes = "根据id查询")
    @GetMapping("/authority/getHouseById/{id}")
    public ResultView getHouseById(@PathVariable Long id) {
        HouseInfo housePo = houseInfoService.getById(id);
        return ResultView.success(housePo);
    }

//    @GetMapping("/authority/getHouseList")
//    @ApiOperation(value = "仓房管理", notes = "查询list")
//    public ResultView getHouseList(@PathParam("name") String name, @PathParam("code") String code) {
//        List<HouseInfo> list = houseInfoService.getHouseList(name, code);
//        return ResultView.success(list);
//    }


    @PostMapping("/authority/getHousePage")
    @ApiOperation(value = "仓房管理", notes = "分页列表")
    public ResultView getHousePage(@RequestBody PageParam pageParam) {
        try {
            IPage<HouseInfo> page = houseInfoService.getHousePage(pageParam);
            return ResultView.success(page);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @PostMapping("/authority/save")
    @ApiOperation(value = "仓房管理", notes = "新增保存")
    public ResultView saveHouse(@RequestBody HouseInfo houseInfo) {
        houseInfo.setId(UUID.randomUUID().toString());
        houseInfo.setUseDate(DateUtils.getDate());

        boolean save = houseInfoService.save(houseInfo);
        if (save){
            return ResultView.success();
        }else{
            return ResultView.error();
        }
    }


    @PostMapping("/authority/update")
    @ApiOperation(value = "仓房管理", notes = "根据id更新")
    public ResultView updateHouse(@RequestBody HouseInfo HouseInfo) {
        boolean b = houseInfoService.updateById(HouseInfo);
        if (b){
            return ResultView.success();
        }else{
            return ResultView.error();
        }

    }

    @GetMapping("/authority/deleteById/{id}")
    @ApiOperation(value = "仓房管理", notes = "根据id删除")
    public ResultView getByIdForHouseDelete(@PathVariable String id) {
        if (houseInfoService.removeById(id)) {
            return ResultView.success();
        }
        return ResultView.error(MyConstant.ID_NULL);
    }


}
