package com.unissoft.syn.controller;


import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.ServletException;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import com.unissoft.syn.model.SynAuthorization;
import com.unissoft.syn.service.SynAuthorizationService;

import io.swagger.annotations.ApiOperation;

/**
 * <p>
 * 授权码 前端控制器
 * </p>
 *
 * @author root
 * @since 2023-04-04
 */
@RestController
@RequestMapping("/syn-authorization")
public class SynAuthorizationController {
	
	@Resource
    private SynAuthorizationService synAuthorizationService;
	
	 /**
	  * 输入授权码
	  * @param request
	  * @param response
	  * @throws ServletException
	  * @throws IOException
	  */
    @PostMapping("/inputsqm")
    public HashMap<String,String> setCookie(String sqm,HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        
    	HashMap<String,String> map = new HashMap<String,String>();
    	boolean falg = synAuthorizationService.checkSqm(request, sqm);
    	if(!falg){
    		map.put( "code", "400");
    		map.put( "msg", "授权码不正确");
    		return map;
    	}
    	
    	Cookie cookie = new Cookie("sqmKey", sqm);
        //设置Maximum Age
        // 过期时间s （默认是-1 关闭浏览器失效）
		cookie.setMaxAge(-1);
        //设置cookie路径为当前项目路径
        cookie.setPath("/");
        //添加cookie
        response.addCookie(cookie);
        map.put( "code", "200");
        map.put( "status", "true");
        return map;
        
    }
    
    
    /**
     * 设置授权码
     */
    /**
	 * 列表
	 * @param pageParam
	 * @return
	 */
	    @PostMapping("/getPageList")
	    @ApiOperation(value = "授权码列表", notes = "分页列表")
	    public ResultView getPageList(@RequestBody PageParam pageParam) {
	        try {
	            IPage<SynAuthorization> pageList = synAuthorizationService.getPageList(pageParam);
	            return ResultView.success(pageList);
	        } catch (Exception e) {
	            e.printStackTrace();
	            return ResultView.error();
	        }
	    }
	  
	  /**
	   * 新增
	   * @param synConfiguration
	   * @return
	   */
	    @PostMapping("/save")
	    @ApiOperation(value = "新增", notes = "")
	    public ResultView save(@RequestBody SynAuthorization synAuthorization) {
	    	synAuthorization.setId(UUID.randomUUID().toString().replaceAll("-", ""));
	    	synAuthorization.setCreateTime(DateUtils.getDate());
	        boolean save = synAuthorizationService.save(synAuthorization);
	        if (save)
	            return ResultView.success();
	        else
	            return ResultView.error();
	    }
	    
	    
	    
	    /**
	     * 修改
	     * @param synConfiguration
	     * @return
	     */
	    @PostMapping("/update")
	    @ApiOperation(value = "修改", notes = "")
	    public ResultView update(@RequestBody SynAuthorization synAuthorization) {
	        boolean b = synAuthorizationService.updateById(synAuthorization);
	        if (b)
	            return ResultView.success();
	        else
	            return ResultView.error();
	    }
	    
	    
	    /**
	     * 删除
	     * @param id
	     * @return
	     */
	    @DeleteMapping("/deleteById/{id}")
	    @ApiOperation(value = "根据id删除", notes = "")
	    public ResultView deleteById(@PathVariable String id) {
	    	boolean b = synAuthorizationService.removeById(id);
	    	if (b)
	            return ResultView.success();
	        else
	            return ResultView.error();
	    }
	
	    
	  //验证授权码是否正确
	    @PostMapping("/checkSqm")
	    public String checkSqm(String sqmValue,HttpServletRequest request) {
			//根据orgCode和sqmValue到表里查询 是否一致
	    	boolean a = synAuthorizationService.checkSqm(request, sqmValue);
	    	
			return sqmValue;
	    }
	    
	
}
