package com.unissoft.syn.controller;


import java.util.UUID;

import javax.annotation.Resource;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import com.unissoft.syn.model.SynConfiguration;
import com.unissoft.syn.service.SynConfigurationService;

import io.swagger.annotations.ApiOperation;

/**
 * <p>
 * 数据同步交换配置 前端控制器
 * </p>
 *
 * @author SunShine
 * @since 2023-03-16
 */
@RestController
@RequestMapping("/syn-configuration")
public class SynConfigurationController {

	@Resource
    private SynConfigurationService synConfigurationService;
	
	/**
	 * 列表
	 * @param pageParam
	 * @return
	 */
	    @PostMapping("/getPageList")
	    @ApiOperation(value = "数据同步交换配置列表", notes = "分页列表")
	    public ResultView getPageList(@RequestBody PageParam pageParam) {
	        try {
	            IPage<SynConfiguration> pageList = synConfigurationService.getPageList(pageParam);
	            return ResultView.success(pageList);
	        } catch (Exception e) {
	            e.printStackTrace();
	            return ResultView.error();
	        }
	    }
	  
	  /**
	   * 新增
	   * @param synConfiguration
	   * @return
	   */
	    @PostMapping("/save")
	    @ApiOperation(value = "新增", notes = "")
	    public ResultView save(@RequestBody SynConfiguration synConfiguration) {
	    	synConfiguration.setId(UUID.randomUUID().toString().replaceAll("-", ""));
	    	synConfiguration.setCreateTime(DateUtils.getDate());
	        boolean save = synConfigurationService.save(synConfiguration);
	        if (save)
	            return ResultView.success();
	        else
	            return ResultView.error();
	    }
	    
	    
	    
	    /**
	     * 修改
	     * @param synConfiguration
	     * @return
	     */
	    @PostMapping("/update")
	    @ApiOperation(value = "修改", notes = "")
	    public ResultView update(@RequestBody SynConfiguration synConfiguration) {
	        boolean b = synConfigurationService.updateById(synConfiguration);
	        if (b)
	            return ResultView.success();
	        else
	            return ResultView.error();
	    }
	    
	    
	    /**
	     * 删除
	     * @param id
	     * @return
	     */
	    @DeleteMapping("/deleteById/{id}")
	    @ApiOperation(value = "根据id删除", notes = "")
	    public ResultView deleteById(@PathVariable String id) {
	    	boolean b = synConfigurationService.removeById(id);
	    	if (b)
	            return ResultView.success();
	        else
	            return ResultView.error();
	    }
}
