package com.unissoft.syn.service.impl;

import com.unissoft.syn.model.SynConfiguration;
import com.unissoft.common.PageParam;
import com.unissoft.syn.mapper.SynConfigurationMapper;
import com.unissoft.syn.service.SynConfigurationService;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import java.text.SimpleDateFormat;
import java.util.Date;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

/**
 * <p>
 * 数据同步交换配置 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-03-16
 */
@Service
public class SynConfigurationServiceImpl extends ServiceImpl<SynConfigurationMapper, SynConfiguration> implements SynConfigurationService {

	
	@Resource
    private SynConfigurationMapper synConfigurationMapper;
	
	
	@Override
	public IPage<SynConfiguration> getPageList(PageParam pageParam) {
		// TODO Auto-generated method stub
		// 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();

        // 查询条件
        String condition = pageParam.getCondition();
        QueryWrapper<SynConfiguration> queryWrapper = new QueryWrapper<>();
        
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
        	SynConfiguration synConfiguration = JSON.parseObject(condition, SynConfiguration.class);
            // 获取查询条件
        	String orgCode = synConfiguration.getOrgCode();
            String systemName = synConfiguration.getSystemName();
            Date startTime = synConfiguration.getStartTime();//开始时间
            Date endTime = synConfiguration.getEndTime();//结束时间

            
            if (!StringUtils.isEmpty(orgCode)){
                queryWrapper.eq("org_code", orgCode);
            }
            if (!StringUtils.isEmpty(systemName)){
                queryWrapper.like("system_name", systemName);
            }
            
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            if(startTime != null && endTime != null){
            	queryWrapper.between("create_time", sdf.format(startTime)+" "+"00:00:00", sdf.format(endTime)+" "+"23:59:59");
            }else if(startTime != null && endTime == null ){
            	queryWrapper.gt("create_time", sdf.format(startTime)+" "+"00:00:00");
            }else if(startTime == null && endTime != null){
            	queryWrapper.lt("create_time", sdf.format(endTime)+" "+"23:59:59");

            }
        }
        queryWrapper.orderByDesc("create_time");
        // 分页对象
        IPage<SynConfiguration> page = new Page<>(pageIndex, pageSize);
        return synConfigurationMapper.selectPage(page, queryWrapper);
	}

    
}
