package com.unissoft.sys.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.basic.model.BasicEnum;
import com.unissoft.common.MyConstant;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import com.unissoft.sys.model.LabelInfo;
import com.unissoft.sys.service.LabelInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.UUID;


/**
 * <p>
 *  标签管理
 * </p>
 *
 * @author root
 * @since 2023-01-31
 */
@Api(tags = "标签管理")
@Slf4j
@RestController
@RequestMapping("/label-info")
public class LabelInfoController {
    private LabelInfoService labelInfoService;
    
    @Autowired
    public void setLabelInfoController(LabelInfoService labelInfoService) {
        this.labelInfoService = labelInfoService;
    }

    @ApiOperation(value = "标签管理", notes = "根据id查询")
    @GetMapping("/getLabelById/{id}")
    public ResultView getLabelById(@PathVariable Long id) {
        LabelInfo LabelPo = labelInfoService.getById(id);
        return ResultView.success(LabelPo);
    }

//    @GetMapping("/authority/getLabelList")
//    @ApiOperation(value = "标签管理", notes = "查询list")
//    public ResultView getLabelList(@PathParam("name") String name, @PathParam("code") String code) {
//        List<LabelInfo> list = labelInfoService.getLabelList(name, code);
//        return ResultView.success(list);
//    }


    @PostMapping("/getLabelPage")
    @ApiOperation(value = "标签管理", notes = "分页列表")
    public ResultView getLabelPage(@RequestBody PageParam pageParam) {
        try {
            IPage<LabelInfo> page = labelInfoService.getLabelPage(pageParam);
            return ResultView.success(page);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @PostMapping("/save")
    @ApiOperation(value = "标签管理", notes = "新增保存")
    public ResultView saveLabel(@RequestBody LabelInfo labelInfo) {
        labelInfo.setId(UUID.randomUUID().toString());
        boolean save = labelInfoService.save(labelInfo);
        if (save){
            return ResultView.success();
        }else{
            return ResultView.error();
        }
    }


    @PostMapping("/update")
    @ApiOperation(value = "标签管理", notes = "根据id更新")
    public ResultView updateLabel(@RequestBody LabelInfo labelInfo) {
        boolean b = labelInfoService.updateById(labelInfo);
        if (b){
            return ResultView.success();
        }else{
            return ResultView.error();
        }

    }

    @GetMapping("/authority/deleteById/{id}")
    @ApiOperation(value = "标签管理", notes = "根据id查询")
    public ResultView getByIdForLabelDelete(@PathVariable String id) {
        if (labelInfoService.removeById(id)) {
            return ResultView.success();
        }
        return ResultView.error(MyConstant.ID_NULL);
    }

    @GetMapping("/getParentsList")
    @ApiOperation(value = "父级列表", notes = "标签父级列表")
    public ResultView getParentsList() {
        try {
            List<LabelInfo> parentsList = labelInfoService.getParentsList();
            return ResultView.success(parentsList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

}
