package com.unissoft.sys.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.common.PageParam;
import com.unissoft.common.ResultView;
import com.unissoft.sys.model.SysOrgInfo;
import com.unissoft.sys.service.SysOrgInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * <p>
 * 单位信息 前端控制器
 * </p>
 *
 * @author root
 * @since 2023-03-20
 */
@Api(tags = "系统管理")
@RestController
@RequestMapping("/sys-org-info")
public class SysOrgInfoController {
    @Resource
    private SysOrgInfoService orgInfoService;

    @PostMapping("/getPageList")
    @ApiOperation(value = "单位信息-分页列表", notes = "分页列表")
    public ResultView getLabelPage(@RequestBody PageParam pageParam) {
        try {
            IPage<SysOrgInfo> pageList = orgInfoService.getPageList(pageParam);
            return ResultView.success(pageList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @PostMapping("/save")
    @ApiOperation(value = "单位信息-新增", notes = "新增保存一条单位信息")
    public ResultView save(@RequestBody SysOrgInfo orgInfo) {
        orgInfo.setId(UUID.randomUUID().toString());
        boolean save = orgInfoService.save(orgInfo);
        if (save){
            return ResultView.success();
        }else{
            return ResultView.error();
        }
    }

    @PostMapping("/update")
    @ApiOperation(value = "单位信息-修改", notes = "修改(根据id)")
    public ResultView updateById(@RequestBody SysOrgInfo orgInfo) {
        boolean update = orgInfoService.updateById(orgInfo);
        if (update){
            return ResultView.success();
        }else{
            return ResultView.error();
        }
    }

    @ApiOperation(value = "根据id获取单位信息", notes = "获取唯一单位信息")
    @GetMapping("/getById/{id}")
    public ResultView getById(@PathVariable String id) {
        return ResultView.success(orgInfoService.getById(id));
    }

    @ApiOperation(value = "根据id删除", notes = "删除唯一单位信息")
    @GetMapping("/deleteById/{id}")
    public ResultView deleteById(@PathVariable String id) {
        return ResultView.success(orgInfoService.removeById(id));
    }

    @ApiOperation(value = "单位信息-查看", notes = "根据用户登录名查询(userName)单位信息")
    @GetMapping("/getOrgInfoByUser/{userName}")
    public ResultView getOrgInfoByUser(@PathVariable String userName) {
        return ResultView.success(orgInfoService.getOrgInfoByUser(userName));
    }

    @ApiOperation(value = "获取单位信息", notes = "获取所有单位信息(list)")
    @GetMapping("/getOrgInfoList")
    public ResultView getOrgInfoList() {
        return ResultView.success(orgInfoService.list());
    }

}
