package com.unissoft.sys.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.basic.model.BasicEnum;
import com.unissoft.common.PageParam;
import com.unissoft.sys.model.LabelInfo;
import com.unissoft.sys.mapper.LabelInfoMapper;
import com.unissoft.sys.service.LabelInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author root
 * @since 2023-01-31
 */
@Service
public class LabelInfoServiceImpl extends ServiceImpl<LabelInfoMapper, LabelInfo> implements LabelInfoService {

    @Resource
    private LabelInfoMapper labelInfoMapper;


    /**
     * 分页查询列表数据
     * 1.使用递归查询数据库,影响数据库性能(未采用)
     * 2.使用java获取所有数据在递归处理数据,在数据量不大的情况下性能较高采用
     *
     * @param pageParam 分页条件
     * @return page
     */
    @Override
    public IPage<LabelInfo> getLabelPage(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();
        // 查询条件
        String condition = pageParam.getCondition();
        // 查询对象
        QueryWrapper<LabelInfo> ew = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            LabelInfo labelInfo = JSON.parseObject(condition, LabelInfo.class);
            // 获取查询条件
            String labelName = labelInfo.getLabelName();
            String labelCode = labelInfo.getLabelCode();
            String labelClass = labelInfo.getLabelClass();
            if (!StringUtils.isEmpty(labelName)){
                ew.like("label_name", labelName);
            }
            if (!StringUtils.isEmpty(labelCode)){
                ew.eq("label_code", labelCode);
            }
            if (!StringUtils.isEmpty(labelClass)){
                ew.eq("label_class", labelClass);
            }
        }
        // 只获取顶级父类作为分页数据
        ew.eq("parent_id", "0");
        IPage<LabelInfo> page = new Page<>(pageIndex, pageSize);
        IPage<LabelInfo> labelPage = labelInfoMapper.getLabelPage(page, ew);
        // 调用子集
        if (labelPage.getSize() > 0) {
            List<LabelInfo> labelInfo = this.queryList();
            // 已经查询定义好的分页数据比对添加子集的数据(已排序,可以减少循环次数)
            labelPage.getRecords().forEach(e ->
                    labelInfo.forEach(l -> {
                        if (e.getId().equals(l.getId())) {
                            e.setChildren(l.getChildren());
                        }
                    })
            );
        }
        return labelPage;
    }

    /**
     * 查询所有字典数据
     *
     * @return page
     */
    private List<LabelInfo> queryList() {
        // 查询对象
        QueryWrapper<LabelInfo> ew = new QueryWrapper<>();
        //ew.orderByDesc("create_time");
        List<LabelInfo> allList = labelInfoMapper.selectList(ew);
        List<LabelInfo> childList = this.getChildren(allList, "0");
        this.fillTree(allList, childList);
        return childList;
    }

    /**
     * 所有数据集分级
     *
     * @param allList  所有数据集
     * @param parentId 定义顶级父级parentId("0")
     * @return list
     */
    private List<LabelInfo> getChildren(List<LabelInfo> allList, String parentId) {
        List<LabelInfo> children = new ArrayList<>();
        for (LabelInfo be : allList) {
            // 遍历出父id等于参数的id,add进子节点集合
            if (be.getParentId().equals(parentId)) {
                children.add(be);
            }
        }
        return children;
    }

    /**
     * 递归拼装树型菜单
     *
     * @param allList   所有数据集
     * @param childList 递归方法
     */
    private void fillTree(List<LabelInfo> allList, List<LabelInfo> childList) {
        if (childList.size() > 0) {
            for (LabelInfo be : childList) {
                List<LabelInfo> childList1 = this.getChildren(allList, be.getId());
                fillTree(allList, childList1);
                be.setChildren(childList1);
            }
        }
    }

    @Override
    public List<LabelInfo> getParentsList() {
        return labelInfoMapper.getParentsList();
    }
}
