package com.unissoft.sys.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unissoft.common.DateUtils;
import com.unissoft.common.PageParam;
import com.unissoft.sys.mapper.SysLogMapper;
import com.unissoft.sys.model.SysLog;
import com.unissoft.sys.service.SysLogService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 运行日志 服务实现类
 * </p>
 *
 * @author root
 * @since 2023-03-01
 */
@Service
public class SysLogServiceImpl extends ServiceImpl<SysLogMapper, SysLog> implements SysLogService {
    @Resource
    private SysLogMapper logMapper;

    @Override
    public IPage<SysLog> getPageList(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();

        // 查询条件
        String condition = pageParam.getCondition();
        QueryWrapper<SysLog> queryWrapper = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            SysLog sysLog = JSON.parseObject(condition, SysLog.class);
            // 获取查询条件
            String orgCode = sysLog.getOrgCode();
            String userRealName = sysLog.getUserRealName();
            Date operationTime = sysLog.getOperationTime();
            if (!StringUtils.isEmpty(orgCode))
                queryWrapper.eq("org_code", orgCode);
            if (!StringUtils.isEmpty(userRealName))
                queryWrapper.like("user_real_name", userRealName);
            if (!StringUtils.isEmpty(operationTime))
                queryWrapper.between("operation_time", operationTime, DateUtils.betweenOneDay(operationTime)[1]);
        }
        queryWrapper.orderByDesc("operation_time");
        // 分页对象
        IPage<SysLog> page = new Page<>(pageIndex, pageSize);
        return logMapper.selectPage(page, queryWrapper);
    }

    @Override
    public List<SysLog> getLogList(String orgCode) {
        QueryWrapper<SysLog> qw = new QueryWrapper<>();
        if (!StringUtils.isEmpty(orgCode))
            qw.eq("org_code", orgCode);
        // 查询当天日志数据
        Date date = new Date();
        qw.between("operation_time", DateUtils.betweenOneDay(date)[0], DateUtils.betweenOneDay(date)[1]);
        // 降序
        qw.orderByDesc("operation_time");
        List<SysLog> sysLogs = logMapper.selectList(qw);
        // 当天数据为空,获取最新10条
        if (sysLogs.size() <= 0) {
            sysLogs = logMapper.selectPage(new Page<>(0, 10), qw).getRecords();
        }
        return sysLogs;
    }

    @Override
    public Object getOnlineList(String orgCode) {
        return logMapper.getOnlineList(orgCode);
    }

}
