package com.unissoft.user.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.unissoft.common.*;
import com.unissoft.user.model.UserChildInfo;
import com.unissoft.user.model.UserInfo;
import com.unissoft.user.service.UserInfoService;
import com.unissoft.utils.IdentifyCodeUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.awt.image.BufferedImage;
import java.util.*;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author root
 * @since 2023-01-17
 */
@Api(tags = "用户管理")
@Slf4j
@RestController
@RequestMapping("/user-info")
public class UserInfoController {

    private UserInfoService userInfoService;

    @Autowired
    public void setUserInfoController(UserInfoService userInfoService) {
        this.userInfoService = userInfoService;
    }

    @ApiOperation(value = "根据id查询", notes = "")
    @GetMapping("/authority/getUserById/{id}")
    public ResultView getUserById(@PathVariable String id) {
        UserChildInfo userPO = userInfoService.getByInfoId(id);
        // 密码不返会,保证安全
        userPO.setUserPassword("");
        return ResultView.success(userPO);
    }


    @PostMapping("/authority/getUserPage")
    @ApiOperation(value = "分页列表", notes = "")
    public ResultView getUserPage(@RequestBody PageParam pageParam) {
        try {
            IPage<UserChildInfo> page = userInfoService.getUserPage(pageParam);
            return ResultView.success(page);
        } catch (Exception e) {
            e.printStackTrace();
            return ResultView.error();
        }
    }

    @PostMapping("/authority/save")
    @ApiOperation(value = "新增", notes = "")
//    @SystemLog(operModul = "系统管理", operType = "用户管理", operDesc = "新增用户信息")
    public ResultView saveUser(@RequestBody UserInfo userInfo) {
        userInfo.setId(UUID.randomUUID().toString());
        userInfo.setBuildTime(DateUtils.getDate());
        userInfo.setUserPassword(MD5Util.getMD5(userInfo.getUserPassword()));
        boolean save = userInfoService.save(userInfo);
        if (save)
            return ResultView.success();
        else
            return ResultView.error();
    }

    @PostMapping("/authority/update")
    @ApiOperation(value = "根据id更新", notes = "")
//    @SystemLog(operModul = "系统管理", operType = "用户管理", operDesc = "修改用户信息")
    public ResultView updateUser(@RequestBody UserInfo userInfo) {
        userInfo.setBuildTime(DateUtils.getDate());
        userInfo.setUserPassword(MD5Util.getMD5(userInfo.getUserPassword()));
        boolean b = userInfoService.updateById(userInfo);
        if (b)
            return ResultView.success();
        else
            return ResultView.error();
    }

    @GetMapping("/authority/deleteById/{id}")
    @ApiOperation(value = "根据id查询", notes = "")
//    @SystemLog(operModul = "系统管理", operType = "用户管理", operDesc = "删除用户信息")
    public ResultView getByIdForUserDelete(@PathVariable String id) {
        if (userInfoService.removeById(id)) {
            return ResultView.success();
        }
        return ResultView.error(MyConstant.ID_NULL);
    }

    @ApiOperation(value = "登录", notes = "登录先获取验证码")
    @PostMapping("/login")
    @SystemLog(value = "用户登录")
    public ResultView userLogin(@RequestParam String userName, @RequestParam String userPassword, HttpServletRequest request, @RequestParam String identifyCode) {
        try {
            if (!StringUtils.isEmpty(userName) && !StringUtils.isEmpty(userPassword)) {
                if (!StringUtils.isEmpty(identifyCode)) {
                    /*
                     * 从session中取出验证码
                     * 1. ServletContext:范围最大,应用程序级别的,整个应用程序都能访问
                     * 2. HttpSession–次之,会话级别的,在当前的浏览器中都能訪问[不论是在同一浏览器开多少窗体,都能够访问],可是换个浏览器就不行了,
                     *     就必须又一次创建session
                     * 3. HttpServletRequest–范围最小,请求级别,请求结束,变量的作用域也结束【也就是仅仅是一次访问,访问结束，这个也结束】
                     */
                    String sessionCode = (String) request.getServletContext().getAttribute("identifyCode");
                    if (identifyCode.equalsIgnoreCase(sessionCode)) {
                        // userId 为唯一值
                        UserInfo one = userInfoService.getOne(new QueryWrapper<UserInfo>().eq("user_name", userName));
                        if (Objects.nonNull(one)) {
                            String md5 = MD5Util.getMD5(userPassword);
                            if (one.getUserPassword().equals(md5)) {
                                // 密码使用完不返给前端(safest)
                                one.setUserPassword("");
                                request.getSession().setAttribute("userLogin", one);
                                // 登录成功更新最后一次登录时间
                                userInfoService.updateLastLoginTime(one.getId());
                                return ResultView.success(one);
                            }
                            return ResultView.error(ResultEnum.CODE_5.getMsg());
                        } else {
                            return ResultView.error(ResultEnum.CODE_5.getMsg());
                        }
                    } else {
                        return ResultView.error(ResultEnum.CODE_4.getMsg());
                    }
                } else {
                    return ResultView.error(ResultEnum.CODE_4_1.getMsg());
                }
            } else {
                return ResultView.error(ResultEnum.CODE_5_1.getMsg());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResultView.error(ResultEnum.CODE_2.getMsg());
    }

    /**
     * 给前端返回一个验证码图片
     */
    @Resource
    private IdentifyCodeUtils utils;

    @GetMapping("/identifyImage")
    @ApiOperation(value = "获取验证码", notes = "")
    public void identifyImage(HttpServletResponse response, HttpServletRequest session) {
        //创建随机验证码
        String identifyCode = utils.getIdentifyCode();
        /*
         * session存入验证码
         * 1. ServletContext:范围最大,应用程序级别的,整个应用程序都能访问
         * 2. HttpSession–次之,会话级别的,在当前的浏览器中都能訪问[不论是在同一浏览器开多少窗体,都能够访问],可是换个浏览器就不行了,
         *     就必须又一次创建session
         * 3. HttpServletRequest–范围最小,请求级别,请求结束,变量的作用域也结束【也就是仅仅是一次访问,访问结束，这个也结束】
         */
        session.getServletContext().setAttribute("identifyCode", identifyCode);
        //根据验证码创建图片
        BufferedImage identifyImage = utils.getIdentifyImage(identifyCode);
        //回传给前端
        utils.responseIdentifyImg(identifyImage, response);
    }

}
