package com.unissoft.user.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unissoft.common.PageParam;
import com.unissoft.user.model.UserChildInfo;
import com.unissoft.user.model.UserInfo;
import com.unissoft.user.mapper.UserInfoMapper;
import com.unissoft.user.service.UserInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author root
 * @since 2023-01-17
 */
@Service
public class UserInfoServiceImpl extends ServiceImpl<UserInfoMapper, UserInfo> implements UserInfoService {
    @Resource
    private UserInfoMapper userInfoMapper;

    @Override
    public IPage<UserChildInfo> getUserPage(PageParam pageParam) {
        // 分页条件
        Integer pageIndex = pageParam.getPageIndex();
        Integer pageSize = pageParam.getPageSize();

        // 查询条件
        String condition = pageParam.getCondition();
        QueryWrapper<UserInfo> queryWrapper = new QueryWrapper<>();
        if (!StringUtils.isEmpty(condition)) {
            // 查询条件转Java对象
            UserInfo userInfo = JSON.parseObject(condition, UserInfo.class);
            // 获取查询条件
            String orgCode = userInfo.getOrgCode();
            String userRealName = userInfo.getUserRealName();
            if (!StringUtils.isEmpty(orgCode))
                queryWrapper.eq("ui.org_code", orgCode);
            if (!StringUtils.isEmpty(userRealName))
                queryWrapper.like("ui.user_real_name", userRealName);
        }
        queryWrapper.orderByDesc("ui.build_time");
        // 分页对象
        IPage<UserChildInfo> page = new Page<>(pageIndex, pageSize);
        return userInfoMapper.getUserPage(page, queryWrapper);
    }

    @Override
    public UserChildInfo getByInfoId(String id) {
        return userInfoMapper.getByInfoId(id);
    }

    @Override
    public void updateLastLoginTime(String id) {
        Map<String, Object> map = new ConcurrentHashMap<>();
        map.put("id", id);
        map.put("lastTime", new Date());
        userInfoMapper.updateLastLoginTime(map);
    }

}
