package com.unissoft.utils;

import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.stream.Collectors;

/**
 * @author qingsong.han
 * @description: 数据集转换工具
 * @create 2022-10-09 10:05
 */
@Component
public class MapConvertUtils {

    /**
     * List<Map<String, String>> 格式数据,先分组在将分组后的value拼接({307308681810054=c89512024085,X1XXXQ2206090069, 307308681810053=X1XXXQ2206090068})
     *
     * @param resultKey    对应 List<Map<String, String>> 中的 list->map->key
     * @param resultValues 对应 List<Map<String, String>> 中的 list->map->value
     * @param mapList      只针对List<Map<String, String>>类型数据
     * @return map
     */
    public Map<String, String> groupJoin(@NotBlank String resultKey, @NotBlank String resultValues, @NotEmpty List<Map<String, String>> mapList) {
        // return map and then thread safe
        Map<String, String> resultMap = new ConcurrentHashMap<>();
        // group
        mapList.stream().collect(
                Collectors.groupingBy(m -> m.get(resultKey))
        ).entrySet().iterator().forEachRemaining(iterator ->
                // join
                resultMap.put(
                        iterator.getKey(),
                        iterator.getValue().stream().map(m -> m.get(resultValues)).collect(Collectors.joining(","))
                )
        );
        return resultMap;
    }

    /**
     * List<String> 类型数据 String拼接
     *
     * @param stringList List<String>
     * @return String->str1,str2,str3...
     */
    public String joiningList(List<String> stringList) {
        if (CollectionUtils.isEmpty(stringList))
            return "";
        return stringList.stream().collect(Collectors.joining(","));
    }

}
